@@ -68,15 +68,15 @@ import           Data.Foldable
 import           Data.Function                                (on)
 import           Data.Hashable
 import           Data.Int                                     (Int64)
-import           Data.List                                    (groupBy)
+import qualified Data.List.NonEmpty                           as NE
 import           Data.Maybe
-import           Data.Text.Prettyprint.Doc                    hiding (column, line')
-import           Data.Text.Prettyprint.Doc.Render.Terminal    (color, bgColor, colorDull, bgColorDull)
-import qualified Data.Text.Prettyprint.Doc.Render.Terminal    as Pretty
 import           Data.Semigroup
 import           Data.Semigroup.Reducer
 import           GHC.Generics
 import           Prelude                                      as P hiding (span)
+import           Prettyprinter                                hiding (column, line')
+import           Prettyprinter.Render.Terminal                (color, bgColor, colorDull, bgColorDull)
+import qualified Prettyprinter.Render.Terminal                as Pretty
 import           System.Console.ANSI
 
 import Text.Trifecta.Delta
@@ -86,9 +86,9 @@ import Text.Trifecta.Util.Pretty
 -- $setup
 --
 -- >>> :set -XOverloadedStrings
--- >>> import Data.Text.Prettyprint.Doc (unAnnotate)
 -- >>> import Data.ByteString (ByteString)
 -- >>> import Data.Monoid (mempty)
+-- >>> import Prettyprinter (unAnnotate)
 -- >>> import Text.Trifecta.Delta
 -- >>> let exampleRendering = rendered mempty ("int main(int argc, char ** argv) { int; }" :: ByteString)
 
@@ -291,8 +291,8 @@ prettyRendering (Rendering d ll _ l f) = nesting $ \k -> columns $ \mn -> go (fr
     margin = fill gutterWidth space <+> separator
     ln y = (sgr gutterEffects (if y == 0 then gutter else margin) <+>)
          $ hcat
-         $ P.map (\g -> sgr (fst (P.head g)) (pretty (P.map snd g)))
-         $ groupBy ((==) `on` fst)
+         $ P.map (\g -> sgr (fst (NE.head g)) (pretty (fmap snd g)))
+         $ NE.groupBy ((==) `on` fst)
          [ a ! (y,i) | i <- [lo..hi] ]
 
 window :: Int64 -> Int64 -> Int64 -> (Int64, Int64)
@@ -340,7 +340,7 @@ instance Renderable (Rendered a) where
 -- >>> unAnnotate (prettyRendering (addCaret (Columns 35 35) exampleRendering))
 -- 1 | int main(int argc, char ** argv) { int; }<EOF>
 --   |                                    ^
-data Caret = Caret !Delta {-# UNPACK #-} !ByteString deriving (Eq,Ord,Show,Data,Typeable,Generic)
+data Caret = Caret !Delta {-# UNPACK #-} !ByteString deriving (Eq,Ord,Show,Data,Generic)
 
 class HasCaret t where
   caret :: Lens' t Caret
@@ -379,7 +379,7 @@ instance Semigroup Caret where
 renderingCaret :: Delta -> ByteString -> Rendering
 renderingCaret d bs = addCaret d $ rendered d bs
 
-data Careted a = a :^ Caret deriving (Eq,Ord,Show,Data,Typeable,Generic)
+data Careted a = a :^ Caret deriving (Eq,Ord,Show,Data,Generic)
 
 instance HasCaret (Careted a) where
   caret f (a :^ c) = (a :^) <$> f c
@@ -446,7 +446,7 @@ addSpan s e r = drawSpan s e .# r
 -- >>> unAnnotate (prettyRendering (addSpan (Columns 35 35) (Columns 38 38) exampleRendering))
 -- 1 | int main(int argc, char ** argv) { int; }<EOF>
 --   |                                    ~~~
-data Span = Span !Delta !Delta {-# UNPACK #-} !ByteString deriving (Eq,Ord,Show,Data,Typeable,Generic)
+data Span = Span !Delta !Delta {-# UNPACK #-} !ByteString deriving (Eq,Ord,Show,Data,Generic)
 
 class HasSpan t where
   span :: Lens' t Span
@@ -467,7 +467,7 @@ instance Hashable Span
 
 -- | Annotate an arbitrary piece of data with a 'Span', typically its
 -- corresponding input location.
-data Spanned a = a :~ Span deriving (Eq,Ord,Show,Data,Typeable,Generic)
+data Spanned a = a :~ Span deriving (Eq,Ord,Show,Data,Generic)
 
 instance HasSpan (Spanned a) where
   span f (a :~ c) = (a :~) <$> f c
@@ -515,7 +515,7 @@ data Fixit = Fixit
     -- ^ 'Span' where the error occurred
   , _fixitReplacement :: !ByteString
     -- ^ Replacement suggestion
-  } deriving (Eq,Ord,Show,Data,Typeable,Generic)
+  } deriving (Eq,Ord,Show,Data,Generic)
 
 makeClassy ''Fixit
 
